﻿using System;
using System.Drawing;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;

namespace TestDrawingOrder
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        MapEngine mapEngine;
        private void Form1_Load(object sender, EventArgs e)
        {
            AddConcentricShapesUsingInternalFeatures();
        //    AddTwoConcentricShapesUsingTransaction();
        }

        private void btnAddShape_Click(object sender, EventArgs e)
        {
            AddAnotherShapeUsingInternalFeatures();
        //    AddAnotherShapeUsingTransaction();
        }

        private void AddConcentricShapesUsingInternalFeatures()
        {
            InMemoryFeatureLayer inMemoryFeatureLayer = new InMemoryFeatureLayer();

            Feature feature1 = new Feature("Polygon((-1 -1, -1 1, 1 1, 1 -1, -1 -1))");
            Feature feature2 = new Feature("Polygon((-2 -2, -2 2, 2 2, 2 -2, -2 -2))");

            inMemoryFeatureLayer.InternalFeatures.Add("feature2", feature2);
            inMemoryFeatureLayer.InternalFeatures.Add("feature1", feature1);

            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            mapEngine = new MapEngine();
            mapEngine.StaticLayers.Add(inMemoryFeatureLayer);

            ShowMap();
        }

        private void AddTwoConcentricShapesUsingTransaction()
        {
            InMemoryFeatureLayer inMemoryFeatureLayer = new InMemoryFeatureLayer();

            Feature feature1 = new Feature("Polygon((-1 -1, -1 1, 1 1, 1 -1, -1 -1))");
            Feature feature2 = new Feature("Polygon((-2 -2, -2 2, 2 2, 2 -2, -2 -2))");

            inMemoryFeatureLayer.FeatureSource.IsTransactionLive = true;
            inMemoryFeatureLayer.FeatureSource.Open();
            inMemoryFeatureLayer.FeatureSource.BeginTransaction();
            inMemoryFeatureLayer.FeatureSource.AddFeature(feature2);
            inMemoryFeatureLayer.FeatureSource.AddFeature(feature1);
            
            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            inMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            mapEngine = new MapEngine();
            mapEngine.StaticLayers.Add(inMemoryFeatureLayer);

            ShowMap();
        }

        private void AddAnotherShapeUsingInternalFeatures()
        {
            Feature feature3 = new Feature("Polygon((0 0, 0 3, 3 3, 3 0, 0 0))");

            InMemoryFeatureLayer inMemoryFeatureLayer = (InMemoryFeatureLayer)mapEngine.StaticLayers[0];
            inMemoryFeatureLayer.InternalFeatures.Add(Guid.NewGuid().ToString(), feature3);

            ShowMap();
        }

        private void AddAnotherShapeUsingTransaction()
        {
            Feature feature3 = new Feature("Polygon((0 0, 0 3, 3 3, 3 0, 0 0))");

            InMemoryFeatureLayer inMemoryFeatureLayer = (InMemoryFeatureLayer)mapEngine.StaticLayers[0];
            inMemoryFeatureLayer.FeatureSource.Open();
            inMemoryFeatureLayer.FeatureSource.AddFeature(feature3);

            ShowMap();
        }

        private void btnReDraw_Click(object sender, EventArgs e)
        {
            ShowMap();
        }

        private void ShowMap()
        {
            Bitmap geoImage = new Bitmap(pictureBox1.Width, pictureBox1.Height);
            mapEngine.OpenAllLayers();
            mapEngine.CurrentExtent = new RectangleShape("Polygon((-3 -3, -3 3, 3 3, 3 -3, -3 -3))");
            mapEngine.Draw(mapEngine.StaticLayers, geoImage, GeographyUnit.DecimalDegree);
            mapEngine.CloseAllLayers();
            pictureBox1.Image = geoImage;
        }

        private void btnShowVersion_Click(object sender, EventArgs e)
        {
            MessageBox.Show(ThinkGeo.MapSuite.Core.MapEngine.GetVersion(), "Version Info");
        }

    }
}
